Tools (xentica\.tools)
======================

.. automodule:: xentica.tools
    :members:

Color Manipulation Functions (xentica\.tools\.color)
----------------------------------------------------

.. automodule:: xentica.tools.color
    :members:
    :undoc-members:
    :show-inheritance:

Genetics Functions (xentica\.tools\.genetics)
---------------------------------------------

.. automodule:: xentica.tools.genetics
    :members:
    :undoc-members:
    :show-inheritance:

CA Rules Functions (xentica\.tools\.rules)
------------------------------------------

.. automodule:: xentica.tools.rules
    :members:
    :undoc-members:
    :show-inheritance:

Math Functions (xentica\.tools\.xmath)
--------------------------------------

.. automodule:: xentica.tools.xmath
    :members:
    :undoc-members:
    :show-inheritance:
